@@ -1,10 +1,10 @@
-import sys
-
 from multisite import SiteID
 
 from .defaults import *  # noqa
 
-sys.stdout.write(f"Settings file {__file__}\n")
+style = color_style()  # noqa: F405
+
+sys.stdout.write(style.MIGRATE_HEADING(f"Settings file {__file__}\n"))  # noqa: F405
 
 SITE_ID = SiteID(default=1)
 EDC_SITES_UAT_DOMAIN = False
